==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/nl/chinese.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "nu",
	"field-weekday": "Dag van de week",
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"dateFormatItem-GyMMMEd": "E d MMM U",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"dateFormat-long": "d MMMM U",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"field-wed-relative+-1": "afgelopen woensdag",
	"dateFormatItem-yyyyQQQ": "QQQ U",
	"dateFormat-full": "EEEE d MMMM U",
	"dateFormatItem-yyyyMEd": "E d-M-y",
	"field-thu-relative+-1": "afgelopen donderdag",
	"dateFormatItem-Md": "d-M",
	"field-era": "Tijdperk",
	"field-year": "Jaar",
	"dateFormatItem-yyyyMMMM": "MMMM U",
	"field-hour": "Uur",
	"field-sat-relative+0": "deze zaterdag",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-day-relative+0": "vandaag",
	"field-thu-relative+0": "deze donderdag",
	"field-day-relative+1": "morgen",
	"dateFormatItem-GyMMMd": "d MMM U",
	"field-day-relative+2": "overmorgen",
	"field-thu-relative+1": "volgende week donderdag",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "U",
	"dateFormatItem-yyyyMMMEd": "E d MMM U",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM U",
	"dateFormatItem-yyyyMMMd": "d MMM U",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "deze zondag",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "volgende week zondag",
	"field-minute": "Minuut",
	"field-dayperiod": "AM/PM",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "gisteren",
	"dateFormatItem-h": "h a",
	"field-day-relative+-2": "eergisteren",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d-M",
	"field-fri-relative+0": "deze vrijdag",
	"field-fri-relative+1": "volgende week vrijdag",
	"field-day": "Dag",
	"field-zone": "Zone",
	"dateFormatItem-y": "U",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "vorig jaar",
	"field-month-relative+-1": "vorige maand",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d-M-y",
	"field-month": "Maand",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "deze dinsdag",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"dateFormat-short": "dd-MM-yy",
	"field-second": "Seconde",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"field-sun-relative+-1": "afgelopen zondag",
	"field-month-relative+0": "deze maand",
	"field-month-relative+1": "volgende maand",
	"dateFormatItem-Ed": "E d",
	"field-week": "Week",
	"dateFormat-medium": "d MMM U",
	"field-year-relative+0": "dit jaar",
	"field-week-relative+-1": "vorige week",
	"dateFormatItem-yyyyM": "M-y",
	"field-year-relative+1": "volgend jaar",
	"dateFormatItem-yyyyQQQQ": "QQQQ U",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM U",
	"field-mon-relative+-1": "afgelopen maandag",
	"dateFormatItem-yyyy": "U",
	"field-week-relative+0": "deze week",
	"field-week-relative+1": "volgende week"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/nl/chinese.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "nu",
	"field-weekday": "Dag van de week",
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"dateFormatItem-GyMMMEd": "E d MMM U",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"dateFormat-long": "d MMMM U",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"field-wed-relative+-1": "afgelopen woensdag",
	"dateFormatItem-yyyyQQQ": "QQQ U",
	"dateFormat-full": "EEEE d MMMM U",
	"dateFormatItem-yyyyMEd": "E d-M-y",
	"field-thu-relative+-1": "afgelopen donderdag",
	"dateFormatItem-Md": "d-M",
	"field-era": "Tijdperk",
	"field-year": "Jaar",
	"dateFormatItem-yyyyMMMM": "MMMM U",
	"field-hour": "Uur",
	"field-sat-relative+0": "deze zaterdag",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-day-relative+0": "vandaag",
	"field-thu-relative+0": "deze donderdag",
	"field-day-relative+1": "morgen",
	"dateFormatItem-GyMMMd": "d MMM U",
	"field-day-relative+2": "overmorgen",
	"field-thu-relative+1": "volgende week donderdag",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "U",
	"dateFormatItem-yyyyMMMEd": "E d MMM U",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM U",
	"dateFormatItem-yyyyMMMd": "d MMM U",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "deze zondag",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "volgende week zondag",
	"field-minute": "Minuut",
	"field-dayperiod": "a.m./p.m.",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "gisteren",
	"dateFormatItem-h": "h a",
	"field-day-relative+-2": "eergisteren",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d-M",
	"field-fri-relative+0": "deze vrijdag",
	"field-fri-relative+1": "volgende week vrijdag",
	"field-day": "Dag",
	"field-zone": "Zone",
	"dateFormatItem-y": "U",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "vorig jaar",
	"field-month-relative+-1": "vorige maand",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d-M-y",
	"field-month": "Maand",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "deze dinsdag",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"dateFormat-short": "dd-MM-yy",
	"field-second": "Seconde",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"field-sun-relative+-1": "afgelopen zondag",
	"field-month-relative+0": "deze maand",
	"field-month-relative+1": "volgende maand",
	"dateFormatItem-Ed": "E d",
	"field-week": "Week",
	"dateFormat-medium": "d MMM U",
	"field-year-relative+0": "dit jaar",
	"field-week-relative+-1": "vorige week",
	"dateFormatItem-yyyyM": "M-y",
	"field-year-relative+1": "volgend jaar",
	"dateFormatItem-yyyyQQQQ": "QQQQ U",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM U",
	"field-mon-relative+-1": "afgelopen maandag",
	"dateFormatItem-yyyy": "U",
	"field-week-relative+0": "deze week",
	"field-week-relative+1": "volgende week"
}
//end v1.x content
);
